==> Slicer3-3.0.2007-12-21-darwin-x86.tar.gz: Slicer3-3.0.2007-12-21-darwin-x86/include/InsightToolkit/gdcm/src/gdcmConfigure.h <==
/*=========================================================================
                                                                                
  Program:   gdcm
  Module:    $RCSfile: gdcmConfigure.h.in,v $
  Language:  C++
  Date:      $Date: 2007/08/20 07:46:05 $
  Version:   $Revision: 1.11 $
                                                                                
  Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
  l'Image). All rights reserved. See Doc/License.txt or
  http://www.creatis.insa-lyon.fr/Public/Gdcm/License.html for details.
                                                                                
     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notices for more information.
                                                                                
=========================================================================*/

#ifndef __gdcmConfigure_h
#define __gdcmConfigure_h

/* This header is configured by GDCM's build process.  */

/*--------------------------------------------------------------------------*/
/* Platform Features                                                        */

/* Byte order.  */
/* #undef GDCM_WORDS_BIGENDIAN */

/* Allow access to UINT32_MAX , cf gdcmCommon.h */
#define __STDC_LIMIT_MACROS

/* Hard code the path to the public dictionary */
#define PUB_DICT_PATH "/usr/local/share/gdcm/"

/* Hardcode the path to GDCM_DATA_ROOT */
#define GDCM_DATA_ROOT ""

/* Usefull in particular for loadshared where the full path
 * to the lib is needed */
#define GDCM_EXECUTABLE_OUTPUT_PATH "/Users/hayes/Slicer3-release-gbt/Slicer3-lib/Insight-build/bin"
#define GDCM_LIBRARY_OUTPUT_PATH    "/Users/hayes/Slicer3-release-gbt/Slicer3-lib/Insight-build/bin"

/* For older gcc / broken platform */
/* #undef GDCM_NO_ANSI_STRING_STREAM */

/* I guess something important */
#define CMAKE_HAVE_STDINT_H
#define CMAKE_HAVE_INTTYPES_H

/* This variable allows you to have helpful debug statement */
/* That are in between #ifdef / endif in the gdcm code */
/* That means if GDCM_DEBUG is OFF there shouldn't be any 'cout' at all ! */
/* only cerr, for instance 'invalid file' will be allowed */
/* #undef GDCM_DEBUG */

/* Whether we are building shared libraries.  */
/* This was important as long as GDCM is LGPL */
#define BUILD_SHARED_LIBS

/* GDCM uses __FUNCTION__ which is not ANSI C, but C99 */
#define GDCM_COMPILER_HAS_FUNCTION


/* GetMacAddress require a lot of include file to access low level API */
#define CMAKE_HAVE_UNISTD_H
#define CMAKE_HAVE_STDLIB_H
#define CMAKE_HAVE_SYS_IOCTL_H
#define CMAKE_HAVE_SYS_SOCKET_H
#define CMAKE_HAVE_SYS_SOCKIO_H
#define CMAKE_HAVE_NET_IF_H
#define CMAKE_HAVE_NETINET_IN_H
#define CMAKE_HAVE_NET_IF_DL_H
#define CMAKE_HAVE_NET_IF_ARP_H
#define HAVE_SA_LEN

/* #undef GDCM_FORCE_BIGENDIAN_EMULATION */

/* For OpenJPEG */
/* #undef OPJ_EXPORTS */
/* #undef OPJ_STATIC */

/*--------------------------------------------------------------------------*/
/* GDCM Versioning                                                          */

/* Version number.  */
#define GDCM_MAJOR_VERSION 1
#define GDCM_MINOR_VERSION 2
#define GDCM_BUILD_VERSION 2
#define GDCM_VERSION "1.2.2"

/*--------------------------------------------------------------------------*/
/* GDCM deprecation mechanism                                               */
/* #undef GDCM_LEGACY_REMOVE */
/* #undef GDCM_LEGACY_SILENT */


#endif

==> Slicer3-3.0.2008-01-17-darwin-x86.tar.gz: Slicer3-3.0.2008-01-17-darwin-x86/include/InsightToolkit/gdcm/src/gdcmConfigure.h <==
/*=========================================================================
                                                                                
  Program:   gdcm
  Module:    $RCSfile: gdcmConfigure.h.in,v $
  Language:  C++
  Date:      $Date: 2007/08/20 07:46:05 $
  Version:   $Revision: 1.11 $
                                                                                
  Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
  l'Image). All rights reserved. See Doc/License.txt or
  http://www.creatis.insa-lyon.fr/Public/Gdcm/License.html for details.
                                                                                
     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notices for more information.
                                                                                
=========================================================================*/

#ifndef __gdcmConfigure_h
#define __gdcmConfigure_h

/* This header is configured by GDCM's build process.  */

/*--------------------------------------------------------------------------*/
/* Platform Features                                                        */

/* Byte order.  */
/* #undef GDCM_WORDS_BIGENDIAN */

/* Allow access to UINT32_MAX , cf gdcmCommon.h */
#define __STDC_LIMIT_MACROS

/* Hard code the path to the public dictionary */
#define PUB_DICT_PATH "/usr/local/share/gdcm/"

/* Hardcode the path to GDCM_DATA_ROOT */
#define GDCM_DATA_ROOT ""

/* Usefull in particular for loadshared where the full path
 * to the lib is needed */
#define GDCM_EXECUTABLE_OUTPUT_PATH "/Users/hayes/Slicer-3-0-release/Slicer3-lib/Insight-build/bin"
#define GDCM_LIBRARY_OUTPUT_PATH    "/Users/hayes/Slicer-3-0-release/Slicer3-lib/Insight-build/bin"

/* For older gcc / broken platform */
/* #undef GDCM_NO_ANSI_STRING_STREAM */

/* I guess something important */
#define CMAKE_HAVE_STDINT_H
#define CMAKE_HAVE_INTTYPES_H

/* This variable allows you to have helpful debug statement */
/* That are in between #ifdef / endif in the gdcm code */
/* That means if GDCM_DEBUG is OFF there shouldn't be any 'cout' at all ! */
/* only cerr, for instance 'invalid file' will be allowed */
/* #undef GDCM_DEBUG */

/* Whether we are building shared libraries.  */
/* This was important as long as GDCM is LGPL */
#define BUILD_SHARED_LIBS

/* GDCM uses __FUNCTION__ which is not ANSI C, but C99 */
#define GDCM_COMPILER_HAS_FUNCTION


/* GetMacAddress require a lot of include file to access low level API */
#define CMAKE_HAVE_UNISTD_H
#define CMAKE_HAVE_STDLIB_H
#define CMAKE_HAVE_SYS_IOCTL_H
#define CMAKE_HAVE_SYS_SOCKET_H
#define CMAKE_HAVE_SYS_SOCKIO_H
#define CMAKE_HAVE_NET_IF_H
#define CMAKE_HAVE_NETINET_IN_H
#define CMAKE_HAVE_NET_IF_DL_H
#define CMAKE_HAVE_NET_IF_ARP_H
#define HAVE_SA_LEN

/* #undef GDCM_FORCE_BIGENDIAN_EMULATION */

/* For OpenJPEG */
/* #undef OPJ_EXPORTS */
/* #undef OPJ_STATIC */

/*--------------------------------------------------------------------------*/
/* GDCM Versioning                                                          */

/* Version number.  */
#define GDCM_MAJOR_VERSION 1
#define GDCM_MINOR_VERSION 2
#define GDCM_BUILD_VERSION 2
#define GDCM_VERSION "1.2.2"

/*--------------------------------------------------------------------------*/
/* GDCM deprecation mechanism                                               */
/* #undef GDCM_LEGACY_REMOVE */
/* #undef GDCM_LEGACY_SILENT */


#endif
